@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.4.6"
+__version__ = "0.5.0"
 
 
 import datetime
@@ -46,6 +46,12 @@ class CuJiraX:
         except ValueError:
             self.testexecution = None
 
+    def set_testplan(self, testplan_key: str):
+        try:
+            self.result_info.testPlanKey = Jirakey(testplan_key)
+        except ValueError:
+            self.result_info.testPlanKey = None
+
     def set_test_environments(self, environments: list):
         self.result_info.testEnvironments = environments
 
@@ -60,7 +66,6 @@ class CuJiraX:
     def to_xray(
             self, 
             cucumber_json: str,
-            testplan_key: str = None, 
             import_result=True, 
             ignore_duplicate=True
         )-> dict:
@@ -96,7 +101,7 @@ class CuJiraX:
                 'parent_testset': self.parent_testset_key,
                 'test_execution': str(ticket_te),
                 'testexecution_name': testexecution_name,
-                'test_plan': testplan_key,
+                'test_plan': self.result_info.testPlanKey,
                 'tests': tests,
                 'test_environments': self.result_info.testEnvironments
             })
@@ -108,7 +113,6 @@ class CuJiraX:
             if import_result:
                 self.result_info.summary = testexecution_name
                 self.result_info.description = self.testexecution_desc or f.description or "TBA"
-                self.result_info.testPlanKey = str(testplan_key) if testplan_key else testplan_key
                 
                 _tests = self._get_results(f.elements, self.jira, ignore_duplicate)
                 
@@ -196,8 +200,6 @@ class CuJiraX:
 
         jira_key = j.get_tests(test_name)
         if jira_key: 
-            print("found test:", jira_key[0])
-            
             # Update all Step Definition in the description
             j.update_issue_field(jira_key[0], fields={"description": "\n".join([s[0] for s in step_definitions])})
             return jira_key[0]
